==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/libs/kasten/core/document/abstractmodel_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTMODEL_P_H
#define ABSTRACTMODEL_P_H

#include "abstractmodel.h"

namespace Kasten {

class AbstractModelPrivate
{
public:
    explicit AbstractModelPrivate(AbstractModel* parent, AbstractModel* baseModel = nullptr);

    virtual ~AbstractModelPrivate();

public:
    AbstractModel* baseModel() const;

public:
    void setBaseModel(AbstractModel* baseModel);

protected:
    AbstractModel* const q_ptr;
    Q_DECLARE_PUBLIC(AbstractModel)

protected:
    AbstractModel* mBaseModel;
};

inline AbstractModelPrivate::AbstractModelPrivate(AbstractModel* parent, AbstractModel* baseModel)
    : q_ptr(parent)
    , mBaseModel(baseModel)
{}

inline AbstractModelPrivate::~AbstractModelPrivate() = default;

inline AbstractModel* AbstractModelPrivate::baseModel() const { return mBaseModel; }
inline void AbstractModelPrivate::setBaseModel(AbstractModel* baseModel) { mBaseModel = baseModel; }

}

#endif

==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/libs/kasten/core/document/abstractmodel_p.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTMODEL_P_H
#define ABSTRACTMODEL_P_H

#include "abstractmodel.h"


namespace Kasten2
{

class AbstractModelPrivate
{
  public:
      explicit AbstractModelPrivate( AbstractModel* parent, AbstractModel* baseModel = 0 );

      virtual ~AbstractModelPrivate();

  public:
    AbstractModel* baseModel() const;

  public:
    void setBaseModel( AbstractModel* baseModel );

  protected:
    AbstractModel* const q_ptr;
    Q_DECLARE_PUBLIC( AbstractModel )

  protected:
    AbstractModel* mBaseModel;
};


inline AbstractModelPrivate::AbstractModelPrivate( AbstractModel* parent, AbstractModel* baseModel )
  : q_ptr( parent ),
    mBaseModel( baseModel )
{}

inline AbstractModel* AbstractModelPrivate::baseModel() const { return mBaseModel; }
inline void AbstractModelPrivate::setBaseModel( AbstractModel* baseModel ) { mBaseModel = baseModel; }

inline AbstractModelPrivate::~AbstractModelPrivate() {}

}

#endif
